# Dev lib [Libdev]
Set of standard functions for development

## Submodules
Submodule | Description
---|----
` libdev.cfg ` | Configuration getting
` libdev.time ` | Time processing
` libdev.gen ` | Code & token generators
` libdev.codes ` | Database ciphers
` libdev.check ` | Checking functions

[PyPI](https://pypi.org/project/libdev/)
